@@ -48,8 +48,8 @@ class ClientMonitor(MonitorStream):
         self._mon2 = await self._mon1.__aenter__()
         return self
 
-    def __aexit__(self, *tb):
-        return self._mon1.__aexit__(*tb)
+    async def __aexit__(self, *tb):
+        return await self._mon1.__aexit__(*tb)
 
     def __aiter__(self):
         self._it = self._mon2.__aiter__()
@@ -69,7 +69,8 @@ class ActorState:
     def __init__(self, msg=None):
         self.msg = msg
 
-    pass
+    def __repr__(self):
+        return "<%s:%r>" % (self.__class__.__name__, self.msg)
 
 
 class BrokenState(ActorState):
