@@ -5,35 +5,10 @@ import os
 import io
 import signal
 import time
-import trio  # signaling
 import anyio
 
-try:
-    Stream = anyio.abc.Stream
-except AttributeError:
-    Stream = anyio.abc.ByteStream
-
-try:
-    from trio import BrokenResourceError as trioBrokenResourceError
-    from trio import Cancelled as trioCancelled
-except ImportError:
-
-    class trioBrokenResourceError(Exception):
-        pass
-
-    class trioCancelled(BaseException):
-        pass
-
-
 from distmqtt.utils import create_queue
 
-try:
-    ClosedResourceError = anyio.exceptions.ClosedResourceError
-    ExceptionGroup = anyio.exceptions.ExceptionGroup
-except AttributeError:
-    ClosedResourceError = anyio.ClosedResourceError
-    ExceptionGroup = anyio.ExceptionGroup
-
 try:
     from contextlib import asynccontextmanager
 except ImportError:
@@ -85,8 +60,10 @@ from . import _version_tuple
 
 import logging
 
-logger = logging.getLogger(__name__)
+Stream = anyio.abc.ByteStream
 
+ClosedResourceError = anyio.ClosedResourceError
+ExceptionGroup = anyio.ExceptionGroup
 
 _client_nr = 0
 
@@ -188,7 +165,7 @@ class StreamCommand:
             raise RuntimeError("Can't explicitly send in simple interaction")
         try:
             await self.client.send(msg)
-        except (ClosedResourceError, trioBrokenResourceError):
+        except ClosedResourceError:
             self.client.logger.info("OERR %d", self.client._client_nr)
 
     async def __call__(self, **kw):
@@ -464,7 +441,7 @@ class SCmd_get_tree(StreamCommand):
         nchain = msg.get("nchain", 0)
         ps = PathShortener(entry.path)
         max_depth = msg.get("max_depth", None)
-        empty = msg.get("add_empty", False)
+        empty = msg.get("empty", False)
         conv = client.conv
 
         if max_depth is not None:
@@ -523,7 +500,7 @@ class SCmd_watch(StreamCommand):
         nchain = msg.get("nchain", 0)
         max_depth = msg.get("max_depth", -1)
         min_depth = msg.get("min_depth", 0)
-        empty = msg.get("add_empty", False)
+        empty = msg.get("empty", False)
 
         async with Watcher(entry) as watcher:
             async with anyio.create_task_group() as tg:
@@ -778,8 +755,7 @@ class ServerClient:
         return await self.cmd_get_internal(msg)
 
     async def cmd_root(self, msg):
-        """Change to a sub-tree.
-        """
+        """Change to a sub-tree."""
         self._chroot(msg.path)
         return self.root.serialize(chop_path=self._chop_path, conv=self.conv)
 
@@ -829,8 +805,7 @@ class ServerClient:
             return {"access": acl.result.data if acl.allows("a") else True}
 
     async def cmd_enum(self, msg, with_data=None, _nulls_ok=None, root=None):
-        """Get all sub-nodes.
-        """
+        """Get all sub-nodes."""
         if root is None:
             root = self.root
         if with_data is None:
@@ -875,8 +850,7 @@ class ServerClient:
         await self.server.drop_node(node.name)
 
     async def cmd_get_value(self, msg, _nulls_ok=None, root=None):
-        """Get a node's value.
-        """
+        """Get a node's value."""
         if "node" in msg and "path" not in msg:
             n = Node(msg.node, cache=self.server.node_cache, create=False)
             return n[msg.tick].serialize(
@@ -900,15 +874,13 @@ class ServerClient:
         return entry
 
     async def cmd_set_value(self, msg, **kw):
-        """Set a node's value.
-        """
+        """Set a node's value."""
         if "value" not in msg:
             raise ClientError("Call 'delete_value' if you want to clear the value")
         return await self._set_value(msg, value=msg.value, **kw)
 
     async def cmd_delete_value(self, msg, **kw):
-        """Delete a node's value.
-        """
+        """Delete a node's value."""
         if "value" in msg:
             raise ClientError("A deleted entry can't have a value")
 
@@ -931,7 +903,7 @@ class ServerClient:
             except ClientError:
                 raise
             except Exception as exc:
-                logger.exception("Err %s: %r", exc, msg)
+                self.logger.exception("Err %s: %r", exc, msg)
                 raise ClientError(repr(exc)) from None
                 # TODO pass exceptions to the client
 
@@ -1125,7 +1097,7 @@ class ServerClient:
                 msg["tock"] = self.server.tock
             try:
                 await self.stream.send_all(packer(msg))
-            except (ClosedResourceError, trioBrokenResourceError):
+            except ClosedResourceError:
                 self.logger.info("ERO%d %r", self._client_nr, msg)
                 self._send_lock = None
                 raise
@@ -1201,7 +1173,7 @@ class ServerClient:
 
                 try:
                     buf = await self.stream.receive_some(4096)
-                except (ConnectionResetError, trioBrokenResourceError):
+                except ConnectionResetError:
                     self.logger.info("DEAD %d", self._client_nr)
                     break
                 if len(buf) == 0:  # Connection was closed.
@@ -1756,8 +1728,7 @@ class Server:
                 self._delete_also_nodes = NodeSet()
 
     def _pack_multiple(self, msg):
-        """
-        """
+        """"""
         # protect against mistakenly encoded multi-part messages
         # TODO use a msgpack extension instead
         if isinstance(msg, Mapping):
@@ -1844,7 +1815,7 @@ class Server:
                     async with anyio.fail_after(10):
                         await self.tock_seen(msg.get("tock", 0))
                         await cmd(msg)
-        except (CancelledError, trioCancelled):
+        except CancelledError:
             self.logger.warning("Cancelled %s", action)
             raise
         except BaseException as exc:
@@ -1962,8 +1933,7 @@ class Server:
         return (host, port)
 
     async def do_send_missing(self):
-        """Task to periodically send "missing …" messages
-        """
+        """Task to periodically send "missing …" messages"""
         self.logger.debug("send-missing started")
         clock = self.cfg.server.ping.gap
         while self.fetch_missing:
@@ -2361,8 +2331,7 @@ class Server:
                 n.report_superseded(lk, local=True)
 
     async def _save(self, writer, shorter, nchain=-1, full=False):
-        """Save the current state.
-        """
+        """Save the current state."""
 
         async def saver(entry):
             if entry.data is NotGiven:
@@ -2510,7 +2479,7 @@ class Server:
             await sd.wait()
 
     async def _sigterm(self):
-        with trio.open_signal_receiver(signal.SIGTERM) as r:
+        async with anyio.open_signal_receiver(signal.SIGTERM) as r:
             async for s in r:
                 for s, sd in self._savers:
                     await s.cancel()
@@ -2660,7 +2629,7 @@ class Server:
             c = ServerClient(server=self, stream=stream)
             self._clients.add(c)
             await c.run()
-        except (trioBrokenResourceError, ClosedResourceError):
+        except ClosedResourceError:
             self.logger.debug("XX %d closed", c._client_nr)
         except BaseException as exc:
             CancelExc = anyio.get_cancelled_exc_class()
@@ -2668,7 +2637,7 @@ class Server:
                 # pylint: disable=no-member
                 exc = exc.filter(lambda e: None if isinstance(e, CancelExc) else e, exc)
             if exc is not None and not isinstance(exc, CancelExc):
-                if isinstance(exc, (trioBrokenResourceError, ClosedResourceError)):
+                if isinstance(exc, ClosedResourceError):
                     self.logger.debug("XX %d closed", c._client_nr)
                 else:
                     self.logger.exception("Client connection killed", exc_info=exc)
