@@ -42,12 +42,12 @@ async def test_83_run(autojump_clock):  # pylint: disable=unused-argument
                 with trio.fail_after(200):
                     await c._test_evt.wait()
             finally:
-                await st.run("data get -rd_ :", do_stdout=False)
+                await st.run("data : get -rd_", do_stdout=False)
             await trio.sleep(11)
 
             logger.info("End sleep")
 
-            r = await st.run("data get :")
+            r = await st.run("data :")
             assert r.stdout == "123\n"
 
             rs = ru.state
